pitchtools.chromatic_pitch_number_to_chromatic_pitch_triple
===========================================================

.. autofunction:: abjad.tools.pitchtools.chromatic_pitch_number_to_chromatic_pitch_triple.chromatic_pitch_number_to_chromatic_pitch_triple
   :noindex:
